==> p11-kit-0.19.1.tar.gz: p11-kit-0.19.1/p11-kit/virtual.h <==
/*
 * Copyright (c) 2013 Red Hat, Inc
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 *     * Redistributions of source code must retain the above
 *       copyright notice, this list of conditions and the
 *       following disclaimer.
 *     * Redistributions in binary form must reproduce the
 *       above copyright notice, this list of conditions and
 *       the following disclaimer in the documentation and/or
 *       other materials provided with the distribution.
 *     * The names of contributors to this software may not be
 *       used to endorse or promote products derived from this
 *       software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
 * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
 * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS
 * FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE
 * COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT,
 * INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING,
 * BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS
 * OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED
 * AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF
 * THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH
 * DAMAGE.
 *
 * Author: Stef Walter <stefw@redhat.com>
 */

#ifndef __P11_VIRTUAL_H__
#define __P11_VIRTUAL_H__

#include "pkcs11.h"
#include "pkcs11x.h"
#include "array.h"

typedef struct {
	CK_X_FUNCTION_LIST funcs;
	void *lower_module;
	p11_destroyer lower_destroy;
} p11_virtual;

CK_X_FUNCTION_LIST      p11_virtual_base;

CK_X_FUNCTION_LIST      p11_virtual_stack;

void                    p11_virtual_init       (p11_virtual *virt,
                                                CK_X_FUNCTION_LIST *funcs,
                                                void *lower_module,
                                                p11_destroyer lower_destroy);

void                    p11_virtual_uninit     (p11_virtual *virt);

bool                    p11_virtual_can_wrap   (void);

CK_FUNCTION_LIST *      p11_virtual_wrap       (p11_virtual *virt,
                                                p11_destroyer destroyer);

bool                    p11_virtual_is_wrapper (CK_FUNCTION_LIST *module);

void                    p11_virtual_unwrap     (CK_FUNCTION_LIST *module);

#endif /* __P11_VIRTUAL_H__ */

==> p11-kit_0.20.2.orig.tar.gz: p11-kit-0.20.2/p11-kit/virtual.h <==
/*
 * Copyright (c) 2013 Red Hat, Inc
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 *     * Redistributions of source code must retain the above
 *       copyright notice, this list of conditions and the
 *       following disclaimer.
 *     * Redistributions in binary form must reproduce the
 *       above copyright notice, this list of conditions and
 *       the following disclaimer in the documentation and/or
 *       other materials provided with the distribution.
 *     * The names of contributors to this software may not be
 *       used to endorse or promote products derived from this
 *       software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
 * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
 * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS
 * FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE
 * COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT,
 * INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING,
 * BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS
 * OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED
 * AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF
 * THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH
 * DAMAGE.
 *
 * Author: Stef Walter <stefw@redhat.com>
 */

#ifndef __P11_VIRTUAL_H__
#define __P11_VIRTUAL_H__

#include "pkcs11.h"
#include "pkcs11x.h"
#include "array.h"

typedef struct {
	CK_X_FUNCTION_LIST funcs;
	void *lower_module;
	p11_destroyer lower_destroy;
} p11_virtual;

extern CK_X_FUNCTION_LIST p11_virtual_base;

extern CK_X_FUNCTION_LIST p11_virtual_stack;

void                    p11_virtual_init       (p11_virtual *virt,
                                                CK_X_FUNCTION_LIST *funcs,
                                                void *lower_module,
                                                p11_destroyer lower_destroy);

void                    p11_virtual_uninit     (p11_virtual *virt);

bool                    p11_virtual_can_wrap   (void);

CK_FUNCTION_LIST *      p11_virtual_wrap       (p11_virtual *virt,
                                                p11_destroyer destroyer);

bool                    p11_virtual_is_wrapper (CK_FUNCTION_LIST *module);

void                    p11_virtual_unwrap     (CK_FUNCTION_LIST *module);

#endif /* __P11_VIRTUAL_H__ */
